@@ -184,9 +184,19 @@ where
                                 _ => unreachable!(),
                             };
 
-                            //
                             extra_stmts.push(ModuleItem::Stmt(Stmt::Decl(decl.fold_with(self))));
 
+                            if !is_class {
+                                let mut scope = self.scope.borrow_mut();
+                                scope
+                                    .exported_bindings
+                                    .entry((ident.sym.clone(), ident.span.ctxt()))
+                                    .or_default()
+                                    .push((ident.sym.clone(), ident.span.ctxt()));
+
+                                drop(scope);
+                            }
+
                             let append_to: &mut Vec<_> = if is_class {
                                 &mut extra_stmts
                             } else {
@@ -230,7 +240,7 @@ where
 
                                 for ident in found.drain(..) {
                                     scope
-                                        .exported_vars
+                                        .exported_bindings
                                         .entry((ident.sym.clone(), ident.span.ctxt()))
                                         .or_default()
                                         .push((ident.sym.clone(), ident.span.ctxt()));
@@ -379,14 +389,18 @@ where
 
                                 let key = orig.to_id();
                                 if scope.declared_vars.contains(&key) {
-                                    scope.exported_vars.entry(key.clone()).or_default().push(
-                                        exported
-                                            .clone()
-                                            .map(|i| (i.sym.clone(), i.span.ctxt()))
-                                            .unwrap_or_else(|| {
-                                                (orig.sym.clone(), orig.span.ctxt())
-                                            }),
-                                    );
+                                    scope
+                                        .exported_bindings
+                                        .entry(key.clone())
+                                        .or_default()
+                                        .push(
+                                            exported
+                                                .clone()
+                                                .map(|i| (i.sym.clone(), i.span.ctxt()))
+                                                .unwrap_or_else(|| {
+                                                    (orig.sym.clone(), orig.span.ctxt())
+                                                }),
+                                        );
                                 }
 
                                 if let Some(ref src) = export.src {
